==> elisa-player_22.12.3.orig.tar.xz: elisa-22.12.3/org.kde.elisa.desktop.cmake <==
[Desktop Entry]
Categories=Qt;KDE;Audio;AudioVideo
Comment=
Exec=elisa %U
GenericName=Music Player
GenericName[ar]=مشغّل صوتي إليسّا
GenericName[az]=Musiqi Pleyeri
GenericName[bg]=Слушане на музика
GenericName[ca]=Reproductor musical
GenericName[ca@valencia]=Reproductor musical
GenericName[cs]=Přehrávač hudby
GenericName[da]=Musikafspiller
GenericName[de]=Audio-Wiedergabe
GenericName[el]=Music Player
GenericName[en_GB]=Music Player
GenericName[es]=Reproductor de música
GenericName[et]=Muusikamängija
GenericName[eu]=Musika jotzailea
GenericName[fi]=Musiikkisoitin
GenericName[fr]=Lecteur multimédia
GenericName[gl]=Reprodutor de música
GenericName[hi]=संगीत चालक
GenericName[hu]=Zenelejátszó
GenericName[ia]=Reproductor musical
GenericName[id]=Pemutar Musik
GenericName[it]=Lettore musicale
GenericName[ja]=音楽プレーヤー
GenericName[ka]=მედია დამკვრელი
GenericName[ko]=음악 재생기
GenericName[lt]=Muzikos grotuvas
GenericName[nl]=Muziekspeler
GenericName[nn]=Musikkspelar
GenericName[pa]=ਸੰਗੀਤ ਪਲੇਅਰ
GenericName[pl]=Odtwarzacz muzyki
GenericName[pt]=Leitor de Música
GenericName[pt_BR]=Reprodutor de músicas
GenericName[ro]=Lector audio
GenericName[ru]=Музыкальный проигрыватель
GenericName[sk]=Hudobný prehrávač
GenericName[sl]=Predvajalnik glasbe
GenericName[sv]=Musikspelare
GenericName[ta]=பாடல் இசைப்பி
GenericName[tr]=Müzik Çalar
GenericName[uk]=Музичний програвач
GenericName[x-test]=xxMusic Playerxx
GenericName[zh_CN]=音乐播放器
GenericName[zh_TW]=音樂播放器
Icon=elisa
Name=Elisa
Name[ar]=إليسّا
Name[az]=Elisa
Name[bg]=Elisa
Name[ca]=Elisa
Name[ca@valencia]=Elisa
Name[cs]=Elisa
Name[da]=Elisa
Name[de]=Elisa
Name[el]=Elisa
Name[en_GB]=Elisa
Name[es]=Elisa
Name[et]=Elisa
Name[eu]=Elisa
Name[fi]=Elisa
Name[fr]=Elisa
Name[gl]=Elisa
Name[hi]=एलिसा
Name[hu]=Elisa
Name[ia]=Elisa
Name[id]=Elisa
Name[it]=Elisa
Name[ja]=Elisa
Name[ka]=Elisa
Name[ko]=Elisa
Name[lt]=Elisa
Name[nl]=Elisa
Name[nn]=Elisa
Name[pa]=ਇਲੀਸਾ
Name[pl]=Elisa
Name[pt]=Elisa
Name[pt_BR]=Elisa
Name[ro]=Elisa
Name[ru]=Elisa
Name[sk]=Elisa
Name[sl]=Elisa
Name[sv]=Elisa
Name[ta]=எலைசா
Name[tr]=Elisa
Name[uk]=Elisa
Name[x-test]=xxElisaxx
Name[zh_CN]=Elisa 音乐播放器
Name[zh_TW]=Elisa
StartupWMClass=elisa
Type=Application
MimeType=audio/aac;audio/mp4;audio/mpeg;audio/mpegurl;audio/vnd.rn-realaudio;audio/vorbis;audio/x-flac;audio/x-mp3;audio/x-mpegurl;audio/x-ms-wma;audio/x-musepack;audio/x-oggflac;audio/x-pn-realaudio;audio/x-scpls;audio/x-speex;audio/x-vorbis;audio/x-wav;application/x-ogm-audio;audio/x-vorbis+ogg;audio/ogg;
SingleMainWindow=true
@ELISA_DBUSACTIVATABLE@

==> elisa-player_23.08.5.orig.tar.xz: elisa-23.08.5/org.kde.elisa.desktop.cmake <==
[Desktop Entry]
Categories=Qt;KDE;Audio;AudioVideo
Comment=
Exec=elisa %U
GenericName=Music Player
GenericName[ar]=مشغّل صوتي إليسّا
GenericName[az]=Musiqi Pleyeri
GenericName[be]=Музычны прайгравальнік
GenericName[bg]=Слушане на музика
GenericName[ca]=Reproductor musical
GenericName[ca@valencia]=Reproductor musical
GenericName[cs]=Přehrávač hudby
GenericName[da]=Musikafspiller
GenericName[de]=Musik-Wiedergabe
GenericName[el]=Music Player
GenericName[en_GB]=Music Player
GenericName[eo]=Muzikludilo
GenericName[es]=Reproductor de música
GenericName[et]=Muusikamängija
GenericName[eu]=Musika jotzailea
GenericName[fi]=Musiikkisoitin
GenericName[fr]=Lecteur multimédia
GenericName[gl]=Reprodutor de música
GenericName[hi]=संगीत चालक
GenericName[hu]=Zenelejátszó
GenericName[ia]=Reproductor musical
GenericName[id]=Pemutar Musik
GenericName[it]=Lettore musicale
GenericName[ja]=音楽プレーヤー
GenericName[ka]=მედია დამკვრელი
GenericName[ko]=음악 재생기
GenericName[lt]=Muzikos grotuvas
GenericName[nl]=Muziekspeler
GenericName[nn]=Musikkspelar
GenericName[pa]=ਸੰਗੀਤ ਪਲੇਅਰ
GenericName[pl]=Odtwarzacz muzyki
GenericName[pt]=Leitor de Música
GenericName[pt_BR]=Reprodutor de músicas
GenericName[ro]=Lector audio
GenericName[ru]=Музыкальный проигрыватель
GenericName[sk]=Hudobný prehrávač
GenericName[sl]=Predvajalnik glasbe
GenericName[sv]=Musikspelare
GenericName[ta]=பாடல் இசைப்பி
GenericName[tr]=Müzik Çalar
GenericName[uk]=Музичний програвач
GenericName[x-test]=xxMusic Playerxx
GenericName[zh_CN]=音乐播放器
GenericName[zh_TW]=音樂播放器
Icon=elisa
Name=Elisa
Name[ar]=إليسّا
Name[az]=Elisa
Name[be]=Elisa
Name[bg]=Elisa
Name[ca]=Elisa
Name[ca@valencia]=Elisa
Name[cs]=Elisa
Name[da]=Elisa
Name[de]=Elisa
Name[el]=Elisa
Name[en_GB]=Elisa
Name[eo]=Elisa
Name[es]=Elisa
Name[et]=Elisa
Name[eu]=Elisa
Name[fi]=Elisa
Name[fr]=Elisa
Name[gl]=Elisa
Name[hi]=एलिसा
Name[hu]=Elisa
Name[ia]=Elisa
Name[id]=Elisa
Name[it]=Elisa
Name[ja]=Elisa
Name[ka]=Elisa
Name[ko]=Elisa
Name[lt]=Elisa
Name[nl]=Elisa
Name[nn]=Elisa
Name[pa]=ਇਲੀਸਾ
Name[pl]=Elisa
Name[pt]=Elisa
Name[pt_BR]=Elisa
Name[ro]=Elisa
Name[ru]=Elisa
Name[sk]=Elisa
Name[sl]=Elisa
Name[sv]=Elisa
Name[ta]=எலைசா
Name[tr]=Elisa
Name[uk]=Elisa
Name[x-test]=xxElisaxx
Name[zh_CN]=Elisa 音乐播放器
Name[zh_TW]=Elisa
StartupWMClass=elisa
Type=Application
MimeType=audio/aac;audio/mp4;audio/mpeg;audio/mpegurl;audio/vnd.rn-realaudio;audio/vorbis;audio/x-flac;audio/x-mp3;audio/x-mpegurl;audio/x-ms-wma;audio/x-musepack;audio/x-oggflac;audio/x-pn-realaudio;audio/x-scpls;audio/x-speex;audio/x-vorbis;audio/x-wav;application/x-ogm-audio;audio/x-vorbis+ogg;audio/ogg;
SingleMainWindow=true
@ELISA_DBUSACTIVATABLE@
